/**
 * @file
 * Defines Javascript behaviors for the cookies module.
 */
(function (Drupal, drupalSettings) {
  /**
   * Define defaults.
   */
  Drupal.behaviors.posthog_cookies = {
    consentGiven() {
      // Allow setting cookies. This replaced "memory" by the default cookie
      // tracking:
      // Note, that only users on which the posthog_js conditions apply to
      // can get tracked, so we need to check, if window.posthog even exists:
      drupalSettings.posthog_js.init_config_json.persistence =
        'localStorage+cookie';
      if (
        window.posthog?.set_config &&
        window.posthog?.config?.persistence !== 'localStorage+cookie'
      ) {
        // @todo Only set if not already set.
        window.posthog.set_config({ persistence: 'localStorage+cookie' });
      }
    },
    consentDenied() {
      const consentDeniedPersistence =
        drupalSettings.posthog_cookies?.consent_denied_persistence ?? 'memory';
      drupalSettings.posthog_js.init_config_json.persistence =
        consentDeniedPersistence;
      if (
        window.posthog?.set_config &&
        window.posthog?.config?.persistence !== consentDeniedPersistence
      ) {
        // @todo Only set if not already set.
        window.posthog.set_config({ persistence: consentDeniedPersistence });
      }
    },

    attach(context) {
      const self = this;
      document.addEventListener('cookiesjsrUserConsent', function (event) {
        const service =
          typeof event.detail.services === 'object'
            ? event.detail.services
            : {};
        if (typeof service.posthog !== 'undefined' && service.posthog) {
          self.consentGiven(context);
        } else {
          self.consentDenied(context);
        }
      });
    },
  };
})(Drupal, drupalSettings);
